/**********************************************
 THIS COMMAND FILE SHOWS HOW TO WORK WITH
  USER-DEFINED FORMATS IN SAS.

 FILENAME:  SUMMARY.SAS
************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
options nodate;
title;

/*ASSIGN A LIBNAME TO THE FOLDER WHERE THE
  DATA WILL BE STORED AND ANOTHER FOR THE FORMATS.
  NOTE: THE FORMATS MUST BE STORED USING LIBNAME LIBRARY*/

libname sasdata2 V9 "c:\temp\sasdata2"; 
libname library  V9 "c:\temp\sasdata2"; 

/*CREATE USER-DEFINED FORMATS*/
proc format lib=library;
  value childfmt 1="oldest"
                 2="next oldest"
                 3="youngest";
  value sexfmt   1="male"
                 2="female";
  value racefmt  1="white"
                 2="black";
run;

data sasdata2.owen;
  infile "owen.dat";            
  input fam_num childnum age sex race w_rank income_c height weight hemo
        vit_c vit_a head_cir fatfold b_weight mot_age b_order m_height
        f_height;

  label fam_num  = "Family ID"
        childnum = "Child Number"
        age      = "Age (Months)"
        w_rank   = "Socioeconomic Status"
        income_c = "Income Per Capita"
        height   = "Height (cm)"
        weight   = "Weight (kg)"
        b_weight = "Birth Weight"
        mot_age  = "Mothers Age at Birth";
run;

/*MODIFY THE DATA SET TO SPECIFY THE FORMATS 
   FOR SELECTED VARIABLES*/
proc datasets lib=sasdata2;
     modify owen;
 format childnum childfmt. sex sexfmt. race racefmt.;
run;

proc contents data=sasdata2.owen;
  title "Contents of SASDATA2.OWEN Permanent SAS Data set";
  title2 "Notice that the formats have been assigned to the variables";
run;

proc freq data=sasdata2.owen;
  table sex*race;
  title "Tabulation Using Formatted Values";
run;

/*SORTING ORDER OF FORMATS*/

proc freq data=sasdata2.owen;
  tables sex;
  title "Default Order"; 
run;
proc freq data=sasdata2.owen order=formatted;
  tables sex; 
  title "Order=Formatted";
run;
proc freq data=sasdata2.owen order=internal;
  tables sex; 
  title "Order=Internal";
run;

/*USING A PERMANENT DATA SET WITH FORMATS*/
libname sasdata2 V9 "c:\temp\sasdata2";
libname library  V9 "c:\temp\sasdata2";

proc freq data=sasdata2.owen;
     tables race sex ;
     title "Using Permanent Formats";
run;

/*CREATE TEMPORARY FORMATS AND ASSIGN THEM
   AS NEEDED IN PROCS*/
proc format;
  value gendfmt   1="1: male"
                  2="2: female";
  value actfmt    1="1: low"
                  2="2: medium"
                  3="3: high";
  value ranfmt    1="1: Yes"
                  2="2: No"; 
run;
 
data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
run;

proc freq data=pulse;
  tables sex activity ran;
  format sex gendfmt. activity actfmt. ran ranfmt.;
  title "Formats Are Assigned Temporarily";
run;

proc means data=pulse;
  class ran;
  var pulse1 pulse2;
  format ran ranfmt.;
run;


/*CREATING A DATA SET FROM A FORMATS CATALOG*/

libname library v9 "c:\temp\sasdata2";
proc format lib=library CNTLOUT=fmtdat;
run;
proc print data=fmtdat;
  title "So This is what is in a format!";
run;

/*MAKE A TRANSPORT FILE*/

libname trans1 xport "c:\temp\labdata\fmtdat.xpt";
proc copy in=work out=trans1;
  select fmtdat;
run;


/*READ IN THE TRANSPORT FILE*/

libname trans1 xport "c:\temp\labdata\fmtdat.xpt";
proc copy in=TRANS1 out=WORK;
run;

/*WRITE OUT FORMATS INTO THE FORMATS CATALOG*/

libname library v9 "c:\temp\sasdata2";
proc format lib=library CNTLIN=fmtdat;
run;

/**************************************************
  TROUBLE-SHOOTING
**************************************************/
/*HOW TO GET SAS TO IGNORE FORMAT PROBLEMS*/

options nofmterr;

/*HOW TO REMOVE FORMATS FROM A PERMANENT SAS DATA SET*/

libname sasdata2 V9 "c:\temp\sasdata2";
proc datasets lib=sasdata2;
	modify owen;
	format _all_ ; 
run;
quit;

title "Formats Have Been Removed From Data Set";
proc contents data=sasdata2.owen;
run;


/*HOW TO DE-ASSIGN A FORMATS LIBRARY AND
   REASSIGN IT TO ANOTHER FOLDER */

libname library clear;
libname library V9 "c:\temp\";
